@@ -80,7 +80,7 @@ dbglm.iteration <- function(y, mu, weights,  nobs, eta, Delta, method, offset, n
      }
 
      # link: 1. logit, 2. logarithmic, 3. Identity, 4. mu-1, 5. mu-2     
-     mu<-linkinv(eta <- eta+ offset) # Aqu he canviat
+     mu<-linkinv(eta <- eta+ offset) 
      Dev <- sum(dev.resids(y,mu,weights))
 
      if (is.finite(any(mu<0)))
@@ -138,4 +138,4 @@ dbglm.iteration <- function(y, mu, weights,  nobs, eta, Delta, method, offset, n
                varmu=variance(mu), dev.resids=dev.resids(y,mu,weights), 
                df.null=df.null,y=y,convcrit=convcrit,H=Hhat,
                rel.gvar=dblm_aux$rel.gvar,eff.rank=dblm_aux$eff.rank, dblm_aux=dblm_aux))
-}
\ No newline at end of file
+}
