@@ -22,8 +22,8 @@
  ldblm<-function(...)  UseMethod("ldblm")
      
 ldblm.formula<-function(formula,data,...,kind.of.kernel=1,
-              metric1="euclidean",metric2=metric1,method="GCV",weights,
-              user_h=NULL,h.range=NULL,noh=10,k.knn=3,rel.gvar=0.95,
+              metric1="euclidean",metric2=metric1,method.h="GCV",weights,
+              user.h=NULL,h.range=NULL,noh=10,k.knn=3,rel.gvar=0.95,
               eff.rank=NULL)
 { 
   # call dbglm
@@ -44,8 +44,8 @@ ldblm.formula<-function(formula,data,...,kind.of.kernel=1,
     
   # y and z are defined--> pass to default method (try for avoid the program crash). 
   try(ans<-ldblm.yz(y=zy$y,z=zy$z,kind.of.kernel=kind.of.kernel,
-        method=method,weights=weights,metric1=metric1,metric2=metric2,
-        user_h=user_h,h.range=h.range,noh=noh,k.knn=k.knn,rel.gvar=rel.gvar,
+        method.h=method.h,weights=weights,metric1=metric1,metric2=metric2,
+        user.h=user.h,h.range=h.range,noh=noh,k.knn=k.knn,rel.gvar=rel.gvar,
         eff.rank=eff.rank)) 
    
   if (class(ans)=="try-error") 
@@ -65,12 +65,12 @@ ldblm.formula<-function(formula,data,...,kind.of.kernel=1,
     ################################
 
 ldblm.yz <- function(y,z,kind.of.kernel=1,metric1="euclidean",
-        metric2=metric1,method="GCV",weights,user_h=NULL,h.range=NULL,
+        metric2=metric1,method.h="GCV",weights,user.h=NULL,h.range=NULL,
         noh=10,k.knn=3,rel.gvar=0.95,eff.rank=NULL,...)
 {
   
    # See if z or distance matrix is defined by the user.
-   require(cluster)
+   # require(cluster)
   
    # control metric. See the auxiliar function
    metric1 <- control_metric(metric1)
@@ -84,19 +84,19 @@ ldblm.yz <- function(y,z,kind.of.kernel=1,metric1="euclidean",
   
    # if metric=gower. the distance matrix D is already the squared.
    if (metric1=="gower")
-    D2_1 <-as.matrix(dist1)
+    D2.1 <-as.matrix(dist1)
    else
-    D2_1 <-as.matrix(dist1)^2 
+    D2.1 <-as.matrix(dist1)^2 
    if (metric2=="gower")
-    D2_2 <-as.matrix(dist2)
+    D2.2 <-as.matrix(dist2)
    else
-    D2_2 <-as.matrix(dist2)^2
+    D2.2 <-as.matrix(dist2)^2
      
-   class(D2_1) <- "D2"
-   class(D2_2) <- "D2"
+   class(D2.1) <- "D2"
+   class(D2.2) <- "D2"
    
-   try(ans <- ldblm.D2(D2_1=D2_1,D2_2=D2_2,y=y,kind.of.kernel=kind.of.kernel,
-     method=method,weights=weights,user_h=user_h,h.range=h.range,noh=noh,
+   try(ans <- ldblm.D2(D2.1=D2.1,D2.2=D2.2,y=y,kind.of.kernel=kind.of.kernel,
+     method.h=method.h,weights=weights,user.h=user.h,h.range=h.range,noh=noh,
      k.knn=k.knn,rel.gvar=rel.gvar,eff.rank=eff.rank)) 
   
    if (class(ans)=="try-error") 
@@ -123,8 +123,8 @@ ldblm.yz <- function(y,z,kind.of.kernel=1,metric1="euclidean",
     ####  dissimilarity distance ####
     #################################
 
-ldblm.dist <- function(dist1,dist2=dist1,y,kind.of.kernel=1,method="GCV",
-           weights,user_h=quantile(dist1,.25),
+ldblm.dist <- function(dist1,dist2=dist1,y,kind.of.kernel=1,method.h="GCV",
+           weights,user.h=quantile(dist1,.25),
            h.range=quantile(as.matrix(dist1),c(.05,0.5)),noh=10,k.knn=3,
            rel.gvar=0.95,eff.rank=NULL,...){
           
@@ -140,8 +140,8 @@ ldblm.dist <- function(dist1,dist2=dist1,y,kind.of.kernel=1,method="GCV",
 
       
    # y and Distance are defined--> pass to dist method (try for avoid the program crash). 
-   try(ans <- ldblm.D2(D2_1=Delta1,D2_2=Delta2,y=y,kind.of.kernel=kind.of.kernel,
-              method=method,weights=weights,user_h=user_h,h.range=h.range,
+   try(ans <- ldblm.D2(D2.1=Delta1,D2.2=Delta2,y=y,kind.of.kernel=kind.of.kernel,
+              method.h=method.h,weights=weights,user.h=user.h,h.range=h.range,
               noh=noh,k.knn=k.knn,rel.gvar=rel.gvar,eff.rank=eff.rank))    
    if (class(ans)=="try-error")
     return(paste("the program failed.Tries to read the help. If the error persists attempts to communicate with us "))
@@ -160,24 +160,24 @@ ldblm.dist <- function(dist1,dist2=dist1,y,kind.of.kernel=1,method="GCV",
     ####  ldblm with D2 distance ####
     #################################
 
-ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
-         user_h=quantile(D2_1,.25)^.5,h.range=quantile(as.matrix(D2_1),c(.05,0.5))^.5,
+ldblm.D2<-function(D2.1,D2.2=D2.1,y,kind.of.kernel=1,method.h="GCV",weights,
+         user.h=quantile(D2.1,.25)^.5,h.range=quantile(as.matrix(D2.1),c(.05,0.5))^.5,
          noh=10,k.knn=3,rel.gvar=0.95,eff.rank=NULL,...){
    
     # control method. See the auxiliar function
-    method <- control_method(method,"ldblm")  
+    method.h <- control_method(method.h,"ldblm")  
    
     # another controls: see the auxiliar function
-    controls <- controls_ldblm(D2_1,D2_2,user_h,method,h.range,noh,k.knn,
+    controls <- controls_ldblm(D2.1,D2.2,user.h,method.h,h.range,noh,k.knn,
             kind.of.kernel,y,weights)
-    user_h <- controls$user_h
+    user.h <- controls$user.h
     h.range <- controls$h.range
     weights <- controls$weights
     ori_weights <- weights
     weights <- weights/sum(weights)
      
    # sequence of bandwidth to be evaluate
-   if (method!="user_h"){
+   if (method.h!="user.h"){
      h_low <- h.range[1]
      h_up <- h.range[2]
      h_vec <- exp(seq(log(h_low),log(h_up),length=noh))
@@ -185,20 +185,20 @@ ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
    n <- length(y) 
 
    # k.knn: three nearest neigbourh
-   h.knn<-h.knn.funct(D2_1^.5,k=k.knn)
+   h.knn<-h.knn.funct(D2.1^.5,k=k.knn)
    
-   # compute the model for each method
-   if (method!="user_h"){
+   # compute the model for each method.h
+   if (method.h!="user.h"){
 
-    if (method=="OCV") OCV <- rep(0,noh) # OCV's for each h(only if method==OCV)
-    if (method=="GCV") GCV <- rep(0,noh) # GCV's for each h(only if method==GCV)
-    if (method=="AIC") AIC <- rep(0,noh) # AIC's for each h(only if method==AIC)
-    if (method=="BIC") BIC <- rep(0,noh) # BIC's for each h(only if method==BIC)
+    if (method.h=="OCV") OCV <- rep(0,noh) # OCV's for each h(only if method==OCV)
+    if (method.h=="GCV") GCV <- rep(0,noh) # GCV's for each h(only if method==GCV)
+    if (method.h=="AIC") AIC <- rep(0,noh) # AIC's for each h(only if method==AIC)
+    if (method.h=="BIC") BIC <- rep(0,noh) # BIC's for each h(only if method==BIC)
     
     i <- 0
     for (h in h_vec){
       # fitted values and Shat for each bandwidth (h) 
-      aux <-pred.train.sample(y,D2_1,D2_2,n,h,h.knn,kind.of.kernel,ori_weights,
+      aux <-pred.train.sample(y,D2.1,D2.2,n,h,h.knn,kind.of.kernel,ori_weights,
                     rel.gvar,eff.rank) 
       i <- i+1
       S <- aux$Shat
@@ -207,20 +207,20 @@ ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
       nu <- sum(diagS)
       
       # Ordinary cross validation criterium to choose the best bandwidth.
-      if (method=="OCV"){
+      if (method.h=="OCV"){
         OCV[i] <-  sum(weights*((y-fitted.values)/(1-diagS))^2 ) # ocv formula
          if (is.nan(OCV[i]))
-          stop(paste("OCV for the bandwidth ",round(h,5), " is a NaN. Try to use another method or h.range"))
+          stop(paste("OCV for the bandwidth ",round(h,5), " is a NaN. Try to use another method.h or h.range"))
          
          if (i==1){
          OCV_opt <- OCV[i]
-         h_opt <- h
+         h.opt <- h
          S_opt <- S
          yhat_opt<-fitted.values
         }else{
          if (OCV_opt > OCV[i]){ # improve the best ocv
             OCV_opt <- OCV[i]   # edit the ocv optim
-            h_opt <- h          
+            h.opt <- h          
             S_opt <- S
             yhat_opt<-fitted.values
          }
@@ -228,20 +228,20 @@ ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
      }else OCV_opt<-NULL
         
      # Generalized cross validation criterium to choose the best bandwidth.
-      if (method=="GCV"){
+      if (method.h=="GCV"){
       
         GCV[i] <-sum(weights*(fitted.values-y)^2)/(n*(1-nu/n)^2)   # gcv formula
         if (is.nan(GCV[i]))
-          stop(paste("GCV for the bandwidth ",round(h,5), " is a NaN. Try to use another method or h.range"))
+          stop(paste("GCV for the bandwidth ",round(h,5), " is a NaN. Try to use another method.h or h.range"))
         if (i==1){
          GCV_opt <- GCV[i]
-         h_opt <- h
+         h.opt <- h
          S_opt <- S
          yhat_opt<-fitted.values
         }else{
          if (GCV_opt > GCV[i]){   # improve the best gcv
             GCV_opt <- GCV[i]     # edit the gcv optim
-            h_opt <- h
+            h.opt <- h
             S_opt <- S
             yhat_opt<-fitted.values
          }
@@ -249,19 +249,19 @@ ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
      }else GCV_opt<-NULL
 
      # Aikaike criterium to choose the best bandwidth.
-      if (method=="AIC"){
+      if (method.h=="AIC"){
         rss<-sum(ori_weights*(fitted.values-y)^2)/n   # residual standard desviation
         AIC[i]<-2*sum(diag(S))+n*log(rss)   # aic formula
 
         if (i==1){
          AIC_opt <- AIC[i]
-         h_opt <- h
+         h.opt <- h
          S_opt <- S
          yhat_opt<-fitted.values
         }else{
          if (AIC_opt > AIC[i]){  # improve the best aic
             AIC_opt <- AIC[i]    # edit the aic optim
-            h_opt <- h
+            h.opt <- h
             S_opt <- S
             yhat_opt<-fitted.values
          }
@@ -269,19 +269,19 @@ ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
      }else AIC_opt<-NULL
 
      # Bayesian criterium to choose the best bandwidth.
-      if (method=="BIC"){
+      if (method.h=="BIC"){
         rss<-sum(ori_weights*(fitted.values-y)^2)/n       # residual standard desviation
         BIC[i]<-n*log(rss)+log(n)*sum(diag(S))  # bic formula
 
         if (i==1){
          BIC_opt <- BIC[i]
-         h_opt <- h
+         h.opt <- h
          S_opt <- S
          yhat_opt<-fitted.values
         }else{
          if (BIC_opt > BIC[i]){      # improve the best bic
             BIC_opt <-BIC[i]         # edit the bic optim
-            h_opt <- h
+            h.opt <- h
             S_opt <- S
             yhat_opt<-fitted.values
          }
@@ -290,14 +290,14 @@ ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
      }
     }
     
-    # if method=user_h --> the model is estimated with the h bandwidth defined by the user
-    if (method=="user_h"){
-      # fitted values and Shat for user_h bandwidth
-      aux <-pred.train.sample(y,D2_1,D2_2,n,h=user_h,h.knn,kind.of.kernel,ori_weights,
+    # if method.h=user.h --> the model is estimated with the h bandwidth defined by the user
+    if (method.h=="user.h"){
+      # fitted values and Shat for user.h bandwidth
+      aux <-pred.train.sample(y,D2.1,D2.2,n, h=user.h, h.knn,kind.of.kernel,ori_weights,
               rel.gvar,eff.rank)    
       S <- aux$Shat
       yhat_opt <- aux$yhat
-      h_opt<-user_h
+      h.opt<-user.h
       
       OCV_opt<-NULL
       GCV_opt<-NULL
@@ -309,13 +309,13 @@ ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
     call<- match.call(expand.dots = FALSE)
 
     # return the next attributes 
-    ans<-list(residuals=y-yhat_opt,fitted.values=yhat_opt,h_opt=h_opt,S=S,
-              y=y,weights=weights,call=call,dist1=D2_1,dist2=D2_2) 
+    ans<-list(residuals=y-yhat_opt,fitted.values=yhat_opt,h.opt=h.opt,S=S,
+              y=y,weights=weights,call=call,dist1=D2.1,dist2=D2.2) 
     
     attr(ans,"kind.of.kernel")<-kind.of.kernel             
-    attr(ans,"method")<-method
-    attr(ans,"dist1")<-D2_1
-    attr(ans,"dist2")<-D2_2
+    attr(ans,"method.h")<-method.h
+    attr(ans,"dist1")<-D2.1
+    attr(ans,"dist2")<-D2.2
     attr(ans,"OCV_opt")<-OCV_opt
     attr(ans,"GCV_opt")<-GCV_opt
     attr(ans,"AIC_opt")<-AIC_opt
@@ -325,11 +325,11 @@ ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
     attr(ans,"rel.gvar")<-rel.gvar
     attr(ans,"eff.rank")<-eff.rank
     
-    if (method!="user_h") attr(ans,"h_vec")<-h_vec  
-    if (method=="OCV") attr(ans,"OCV")<-OCV
-    if (method=="GCV") attr(ans,"GCV")<-GCV
-    if (method=="AIC") attr(ans,"AIC")<-AIC
-    if (method=="BIC") attr(ans,"BIC")<-BIC
+    if (method.h!="user.h") attr(ans,"h_vec")<-h_vec  
+    if (method.h=="OCV") attr(ans,"OCV")<-OCV
+    if (method.h=="GCV") attr(ans,"GCV")<-GCV
+    if (method.h=="AIC") attr(ans,"AIC")<-AIC
+    if (method.h=="BIC") attr(ans,"BIC")<-BIC
    
     class(ans)<-"ldblm"
     return(ans)
@@ -340,8 +340,8 @@ ldblm.D2<-function(D2_1,D2_2=D2_1,y,kind.of.kernel=1,method="GCV",weights,
     ####  ldblm with Gram ####
     ##########################
 
-ldblm.Gram <- function(G1,G2=G1,y,kind.of.kernel=1,method="GCV",weights,
-         user_h=NULL,h.range=NULL,noh=10,k.knn=3,rel.gvar=0.95,
+ldblm.Gram <- function(G1,G2=G1,y,kind.of.kernel=1,method.h="GCV",weights,
+         user.h=NULL,h.range=NULL,noh=10,k.knn=3,rel.gvar=0.95,
          eff.rank=NULL,...){
     
    # stop if class of distance matrix is not D2      
@@ -351,12 +351,12 @@ ldblm.Gram <- function(G1,G2=G1,y,kind.of.kernel=1,method="GCV",weights,
     stop("for a ldblm.Gram method the class of the distance matrix G2 must be 'Gram'")   
    
    # converts G to D2
-   D2_1 <- GtoD2(G1)
-   D2_2 <- GtoD2(G2) 
+   D2.1 <- GtoD2(G1)
+   D2.2 <- GtoD2(G2) 
     
    # y and Distance are defined--> pass to dist method (try for avoid the program crash). 
-   try(ans <- ldblm.D2(D2_1=D2_1,D2_2=D2_2,y=y,kind.of.kernel=kind.of.kernel,
-              method=method,user_h=user_h,h.range=h.range,noh=noh,k.knn=k.knn,
+   try(ans <- ldblm.D2(D2.1=D2.1,D2.2=D2.2,y=y,kind.of.kernel=kind.of.kernel,
+              method.h=method.h,user.h=user.h,h.range=h.range,noh=noh,k.knn=k.knn,
               rel.gvar=rel.gvar,eff.rank=eff.rank))    
    if (class(ans)=="try-error")
     return(paste("the program failed.Tries to read the help. If the error persists attempts to communicate with us "))
